# AIdea CLI #

Official AIdea command line tool for https://aidea-web.tw.

## Installation

Make sure you have installed both Python 3 and `pip` package manager.

Run `pip install aidea` to install AIdea CLI.

## Commands

The command line tool supports the following commands:

```
aidea login              Login CLI
aidea topics list        List available topics
aidea topics files       List downloadable files
aidea topics download    Download topic files
aidea topics submit      Make a new submission
```
## License

The AIdea CLI is released under the [Apache 2.0 license](LICENSE).
